@@ -42,7 +42,7 @@
 
 static int pc_debug = 1;
 static char *version =
-	"$Id: ines_cs.c,v 1.39 2004/12/20 02:36:12 fmhess Exp $";
+	"$Id: ines_cs.c,v 1.41 2005/06/05 19:20:51 fmhess Exp $";
 
 /* Parameters that can be set with 'insmod' */
 
@@ -565,13 +565,13 @@ void ines_pcmcia_cleanup_module(void)
     }
 }
 
-int ines_pcmcia_attach(gpib_board_t *board);
-int ines_pcmcia_accel_attach(gpib_board_t *board);
+int ines_pcmcia_attach(gpib_board_t *board, gpib_board_config_t config);
+int ines_pcmcia_accel_attach(gpib_board_t *board, gpib_board_config_t config);
 void ines_pcmcia_detach(gpib_board_t *board);
 
-gpib_interface_t ines_pcmcia_interface =
+gpib_interface_t ines_pcmcia_unaccel_interface =
 {
-	name: "ines_pcmcia",
+	name: "ines_pcmcia_unaccel",
 	attach: ines_pcmcia_attach,
 	detach: ines_pcmcia_detach,
 	read: ines_read,
@@ -625,6 +625,34 @@ gpib_interface_t ines_pcmcia_accel_interface =
 	return_to_local: ines_return_to_local,
 };
 
+gpib_interface_t ines_pcmcia_interface =
+{
+	name: "ines_pcmcia",
+	attach: ines_pcmcia_accel_attach,
+	detach: ines_pcmcia_detach,
+	read: ines_accel_read,
+	write: ines_accel_write,
+	command: ines_command,
+	take_control: ines_take_control,
+	go_to_standby: ines_go_to_standby,
+	request_system_control: ines_request_system_control,
+	interface_clear: ines_interface_clear,
+	remote_enable: ines_remote_enable,
+	enable_eos: ines_enable_eos,
+	disable_eos: ines_disable_eos,
+	parallel_poll: ines_parallel_poll,
+	parallel_poll_configure: ines_parallel_poll_configure,
+	parallel_poll_response: ines_parallel_poll_response,
+	line_status: ines_line_status,
+	update_status: ines_update_status,
+	primary_address: ines_primary_address,
+	secondary_address: ines_secondary_address,
+	serial_poll_response: ines_serial_poll_response,
+	serial_poll_status: ines_serial_poll_status,
+	t1_delay: ines_t1_delay,
+	return_to_local: ines_return_to_local,
+};
+
 int ines_common_pcmcia_attach( gpib_board_t *board )
 {
 	ines_private_t *ines_priv;
@@ -657,7 +685,7 @@ int ines_common_pcmcia_attach( gpib_board_t *board )
 	return 0;
 }
 
-int ines_pcmcia_attach( gpib_board_t *board )
+int ines_pcmcia_attach( gpib_board_t *board , gpib_board_config_t config)
 {
 	ines_private_t *ines_priv;
 	int retval;
@@ -671,7 +699,7 @@ int ines_pcmcia_attach( gpib_board_t *board )
 	return 0;
 }
 
-int ines_pcmcia_accel_attach( gpib_board_t *board )
+int ines_pcmcia_accel_attach( gpib_board_t *board , gpib_board_config_t config)
 {
 	ines_private_t *ines_priv;
 	int retval;
